﻿using DevExpress.Xpf.Core;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Web.Script.Serialization;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Windows.Threading;
using TimeTecAPIDemo.Model;

namespace TimeTecAPIDemo
{
    /// <summary>
    /// Interaction logic for Login.xaml
    /// </summary>
    public partial class Login
    {
        public static string SecurityToken = "";
        public static string Username = "";
        public static string CompanyID = "";
        public static string Status = "";
        public static string ErrorMessage = "";
        WebServiceSDK.WebServiceTimeTecAPISoapClient WS = new WebServiceSDK.WebServiceTimeTecAPISoapClient();
        WebServiceSDK.WebServiceSoapHeader SoapHeader = new WebServiceSDK.WebServiceSoapHeader();

        public Login()
        {
            InitializeComponent();

            #region Check Remember Me
            try
            {
                string filename = "configuration.cfg";
                string line = "";
                bool remembered = false;
                if (File.Exists(filename))
                {
                    using (TextReader tr = new StreamReader(filename))
                    {
                        while ((line = tr.ReadLine()) != null)
                        {
                            string[] l = line.Split(new string[] { "_seperator_" }, StringSplitOptions.None);
                            if (l[0] == "Username")
                            {
                                txtUsername.Text = l[1];
                                remembered = true;
                            }
                            else if (l[0] == "Password")
                            {
                                txtPassword.Password = l[1];
                                remembered = true;
                            }
                        }
                        tr.Close();
                    }
                }
                if (remembered)
                    checkboxRememberMe.IsChecked = true;
                else
                    checkboxRememberMe.IsChecked = false;
            }
            catch { }
            #endregion
        }

        private void SaveConfiguration()
        {
            try
            {
                FileStream fs = null;
                string filename = "configuration.cfg";
                string line = "";
                string newline = "";
                string stringInFile = "";
                bool replaced = false;
                if (!File.Exists(filename))
                {
                    //Create
                    using (fs = File.Create(filename))
                    {
                    }
                    fs.Close();
                }
                if (File.Exists(filename))
                {
                    stringInFile = File.ReadAllText(filename);

                    using (TextReader tr = new StreamReader(filename))
                    {
                        while ((line = tr.ReadLine()) != null)
                        {
                            string[] l = line.Split(new string[] { "_seperator_" }, StringSplitOptions.None);
                            if (l[0] == "Username")
                            {
                                //Replace
                                newline = "Username_seperator_" + txtUsername.Text;
                                stringInFile = stringInFile.Replace(line, newline);
                                replaced = true;
                            }
                            else if (l[0] == "Password")
                            {
                                //Replace
                                newline = "Password_seperator_" + txtPassword.Password;
                                stringInFile = stringInFile.Replace(line, newline);
                                replaced = true;
                            }
                        }
                        tr.Close();
                    }
                    if (replaced)
                    {
                        File.WriteAllText(filename, stringInFile);
                    }
                    if (!replaced)
                    {
                        //Write
                        using (StreamWriter sw = new StreamWriter(filename, append: true))
                        {
                            sw.WriteLine("Username_seperator_" + txtUsername.Text);
                            sw.WriteLine("Password_seperator_" + txtPassword.Password);
                            sw.Close();
                        }
                    }
                    
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString());
            }
        }

        #region Buttons Functions
        private void btnClose_Click(object sender, RoutedEventArgs e)
        {
            //Close login window
            Close();
        }

        private void btnLogin_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                string ErrorMessage = "";
                Username = txtUsername.Text.ToString();
                string Password = txtPassword.Password.ToString();
                this.Cursor = Cursors.Wait;
                BackgroundWorker worker = new BackgroundWorker();
                worker.DoWork += delegate(object s, DoWorkEventArgs args)
                {
                    //Different thread
                    this.Dispatcher.Invoke((Action)(() =>
                    {
                        if (checkboxRememberMe.IsChecked == true)
                        {
                            SaveConfiguration();
                        }
                        else
                        {
                            //Clear configuration.cfg
                            string filename = "configuration.cfg";
                            if (File.Exists(filename))
                            {
                                File.WriteAllText(filename, "");
                            }
                        }
                    }));

                    string json = WS.WebServiceLogin(Username, Password);

                    JavaScriptSerializer js = new JavaScriptSerializer();
                    Dictionary<string, object> JsonResult = js.Deserialize<Dictionary<string, object>>(json);
                    Dictionary<string, object> WSResult = new Dictionary<string, object>();
                    ErrorMessage = JsonResult["ErrorMessage"].ToString();

                    if (ErrorMessage == "")
                    {
                        WSResult = (Dictionary<string, object>)JsonResult["Result"];
                        SecurityToken = WSResult["SecurityToken"].ToString();
                        Status = WSResult["Status"].ToString();

                        if (SecurityToken != "")
                        {
                            SoapHeader.SecurityToken = SecurityToken;
                        }
                        //Get company ID
                        string json_companyid = WS.GetCompanyID(SoapHeader);
                        Dictionary<string, object> JsonResult_companyid = js.Deserialize<Dictionary<string, object>>(json_companyid);
                        Dictionary<string, object> WSResult_companyid = new Dictionary<string, object>();
                        ErrorMessage = JsonResult_companyid["ErrorMessage"].ToString();
                        if (ErrorMessage == "")
                        {
                            WSResult_companyid = (Dictionary<string, object>)JsonResult_companyid["Result"];
                            CompanyID = WSResult_companyid["CompanyID"].ToString();
                        }

                        //Different thread
                        this.Dispatcher.Invoke((Action)(() =>
                        {
                            Function.RefreshSDK();
                            MainWindow main = new MainWindow();
                            App.Current.MainWindow = main;
                            this.Close();
                            main.Show();
                        }));
                    }
                    else
                    {
                        MessageBox.Show(ErrorMessage);
                    }
                };
                worker.RunWorkerAsync();
                while (worker.IsBusy)
                {
                    System.Threading.Thread.Sleep(100);
                    MainWindow.DoEvents();
                }
                this.Cursor = Cursors.Arrow;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString());
            }
        }

        private void btnMinimize_Click(object sender, RoutedEventArgs e)
        {
            this.WindowState = WindowState.Minimized;
        }
        #endregion
    }
}
