﻿using DevExpress.Xpf.Editors;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using TimeTecAPIDemo.Model;

namespace TimeTecAPIDemo
{
    /// <summary>
    /// Interaction logic for Log.xaml
    /// </summary>
    public partial class Logs : UserControl
    {
        public Logs()
        {
            InitializeComponent();
            LoadData();
        }

        public void LoadData()
        {
            this.Cursor = Cursors.Wait;
            BackgroundWorker worker = new BackgroundWorker();
            worker.RunWorkerAsync();
            worker.DoWork += delegate(object s, DoWorkEventArgs args)
            {
                try
                {
                    #region Initialize table Log
                    if (Function.logresult == null)
                    {
                        //Different thread
                        this.Dispatcher.Invoke((Action)(() =>
                        {
                            SetCheckTime("This month");
                        }));
                        //Different thread
                        this.Dispatcher.Invoke((Action)(() =>
                        {
                            Function.LogCheckTimeFrom = Convert.ToDateTime(deCheckTimeFrom.EditValue).ToString("yyyy-MM-dd");
                            Function.LogCheckTimeTo = Convert.ToDateTime(deCheckTimeTo.EditValue).ToString("yyyy-MM-dd");
                            Function.LogRecordStartFrom = "0";
                            Function.LogLimitRecordShow = "25";
                            Function.logresult = Function.LoadDataFromWebservice("AllLog");
                        }));
                    }
                    #endregion
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.ToString());
                }
            };
            worker.RunWorkerCompleted += delegate(object s, RunWorkerCompletedEventArgs args)
            {
                grid.ItemsSource = Function.logresult;
                this.Cursor = Cursors.Arrow;
                copyright.Text = copyright.Text.Replace("2015", DateTime.Now.Year.ToString());
            };
        }

        #region Validation
        private void NumberValidationTextBox(object sender, TextCompositionEventArgs e)
        {
            Regex regex = new Regex("[^0-9]+");
            e.Handled = regex.IsMatch(e.Text);
        }
        #endregion

        #region ComboBox
        private void cbPeriod_Loaded(object sender, RoutedEventArgs e)
        {
            List<string> data = new List<string>();
            data.Add("Select recent");
            data.Add("Today");
            data.Add("This week");
            data.Add("This month");
            data.Add("Last week");
            data.Add("Last month");

            var comboBox = sender as ComboBoxEdit;
            comboBox.ItemsSource = data;
            comboBox.SelectedIndex = 0;
        }

        private void cbShowFrom_Loaded(object sender, RoutedEventArgs e)
        {
            List<string> data = new List<string>();
            data.Add("0");
            data.Add("50");
            data.Add("100");
            data.Add("250");
            data.Add("500");
            data.Add("1000");

            var comboBox = sender as ComboBoxEdit;
            comboBox.ItemsSource = data;
            comboBox.SelectedIndex = 0;
        }

        private void cbNoOfRecordShow_Loaded(object sender, RoutedEventArgs e)
        {
            List<string> data = new List<string>();
            data.Add("25");
            data.Add("50");
            data.Add("100");
            data.Add("250");
            data.Add("500");
            data.Add("1000");

            var comboBox = sender as ComboBoxEdit;
            comboBox.ItemsSource = data;
            comboBox.SelectedIndex = 0;
        }

        private void cbPeriod_SelectedIndexChanged(object sender, RoutedEventArgs e)
        {
            var comboBox = sender as ComboBoxEdit;

            string value = comboBox.SelectedItem as string;

            if (value != "Select recent")
            {
                SetCheckTime(value);
            }
        }

        private void SetCheckTime(string value)
        {
            DayOfWeek weekStart = DayOfWeek.Monday;
            DateTime StartingDate = DateTime.Today;
            DateTime EndingDate = DateTime.Today;

            while (StartingDate.DayOfWeek != weekStart)
                StartingDate = StartingDate.AddDays(-1);

            switch (value)
            {
                case "Today":
                    StartingDate = new DateTime(DateTime.Today.Year, DateTime.Today.Month, DateTime.Today.Day);
                    EndingDate = new DateTime(DateTime.Today.Year, DateTime.Today.Month, DateTime.Today.Day);
                    break;
                case "This week":
                    EndingDate = StartingDate.AddDays(6);
                    break;
                case "This month":
                    StartingDate = new DateTime(StartingDate.Year, StartingDate.Month, 1);
                    EndingDate = StartingDate.AddMonths(1).AddDays(-1);
                    break;
                case "Last week":
                    StartingDate = StartingDate.AddDays(-7);
                    EndingDate = StartingDate.AddDays(6);
                    break;
                case "Last month":
                    StartingDate = new DateTime(StartingDate.Year, StartingDate.Month, 1);
                    EndingDate = StartingDate.AddDays(-1);
                    StartingDate = StartingDate.AddMonths(-1);
                    break;
            }
            deCheckTimeFrom.EditValue = StartingDate;
            deCheckTimeTo.EditValue = EndingDate;
        }
        #endregion

        #region Buttons Functions
        private void btnRefreshGrid_Click(object sender, RoutedEventArgs e)
        {
            this.Cursor = Cursors.Wait;
            BackgroundWorker worker = new BackgroundWorker();
            worker.RunWorkerAsync();
            worker.DoWork += delegate(object s, DoWorkEventArgs args)
            {
                try
                {
                    Function.logresult = Function.LoadDataFromWebservice("AllLog");

                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.ToString());
                }
            };
            worker.RunWorkerCompleted += delegate(object s, RunWorkerCompletedEventArgs args)
            {
                grid.BeginDataUpdate();
                grid.ItemsSource = Function.logresult;
                grid.EndDataUpdate();
                grid.RefreshData();
                this.Cursor = Cursors.Arrow;
            };
        }

        private void btnSearch_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                if (deCheckTimeFrom.EditValue != null && deCheckTimeTo.EditValue != null)
                {
                    DateTime CheckTimeFrom = Convert.ToDateTime(deCheckTimeFrom.EditValue);
                    DateTime CheckTimeTo = Convert.ToDateTime(deCheckTimeTo.EditValue);
                    int DaysInMonth = DateTime.DaysInMonth(CheckTimeFrom.Year, CheckTimeFrom.Month);
                    if (CheckTimeFrom <= CheckTimeTo)
                    {
                        TimeSpan timespan = CheckTimeTo.Subtract(CheckTimeFrom);
                        int daycount = Convert.ToInt32(timespan.Days) + 1;

                        if (daycount <= DaysInMonth)
                        {
                            Function.LogCheckTimeFrom = Convert.ToDateTime(CheckTimeFrom).ToString("yyyy-MM-dd");
                            Function.LogCheckTimeTo = Convert.ToDateTime(CheckTimeTo).ToString("yyyy-MM-dd");
                            Function.LogRecordStartFrom = cbShowFrom.SelectedItem.ToString();
                            Function.LogLimitRecordShow = cbNoOfRecordShow.SelectedItem.ToString();
                            Function.LogUserID = txtUserID.Text;

                            #region Load Log Data
                            if (txtUserID.Text != "")
                            {
                                Function.logresult = Function.LoadDataFromWebservice("Log");
                                grid.ItemsSource = Function.logresult;
                            }
                            else
                            {
                                Function.logresult = Function.LoadDataFromWebservice("AllLog");
                                grid.ItemsSource = Function.logresult;
                            }
                            #endregion
                        }
                        else
                            MessageBox.Show("Maximum search period is one month");
                    }
                    else
                    {
                        MessageBox.Show("Check Time To must be greater than Check Time From");
                    }
                }
                else
                {
                    MessageBox.Show("Please select a valid date");
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString());
            }
        }

        private void btnClose_Click(object sender, RoutedEventArgs e)
        {
            Window parentWindow = Window.GetWindow(this);
            parentWindow.Close();
        }

        private void btnMinimize_Click(object sender, RoutedEventArgs e)
        {
            Window parentWindow = Window.GetWindow(this);
            parentWindow.WindowState = WindowState.Minimized;
        }
        #endregion

    }
}
