﻿using DevExpress.Xpf.Editors;
using DevExpress.Xpf.WindowsUI;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using TimeTecAPIDemo.Model;

namespace TimeTecAPIDemo
{
    /// <summary>
    /// Interaction logic for MainView.xaml
    /// </summary>
    public partial class MainView : UserControl
    {
        public MainView()
        {
            InitializeComponent();
            LicenseUserPanel.Visibility = Visibility.Hidden;
            LicenseLoginUserPanel.Visibility = Visibility.Hidden;
            LicenseTerminalPanel.Visibility = Visibility.Hidden;

            if (Login.SecurityToken != "")
            {
                BindSidePanel(Login.SecurityToken);
                copyright.Text = copyright.Text.Replace("2015", DateTime.Now.Year.ToString());
            }
        }

        public void BindSidePanel(string SecurityToken)
        {
            try
            {
                txtUsername.Text = Login.Username;
                txtCompanyID.Text = Login.CompanyID;
                txtLastUpdate.Text = Function.lastupdate;
                txtTotalTerminal.Text = Function.totalterminal.ToString();
                txtTotalUser.Text = Function.totaluser.ToString();

                if (Function.ApiLimit != "")
                    txtApiLimit.Text = Function.ApiLimit;
                else
                {
                    ApiLimitObj a = Model.Function.LoadDataFromWebservice("ApiLimit") as ApiLimitObj;
                    if (a != null)
                        txtApiLimit.Text = a.ApiLimit.ToString();
                }

                //Get Available License
                if (Function.availablelicense != null)
                {
                    for (int i = 0; i < Function.availablelicense.Count; i++)
                    {
                        if (Function.availablelicense[i].Type == "User")
                        {
                            LicenseUserPanel.Visibility = Visibility.Visible;
                            txtTotalLicenseUser.Text = Function.availablelicense[i].Unit;
                            txtExpiryLicenseUser.Text = Function.availablelicense[i].ExpiryDate;
                            txtRemainingLicenseUser.Text = Function.availablelicense[i].RemainingLicenseUnit;
                        }
                        else if (Function.availablelicense[i].Type == "LoginUser")
                        {
                            LicenseLoginUserPanel.Visibility = Visibility.Visible;
                            txtTotalLicenseLoginUser.Text = Function.availablelicense[i].Unit;
                            txtExpiryLicenseLoginUser.Text = Function.availablelicense[i].ExpiryDate;
                            txtRemainingLicenseLoginUser.Text = Function.availablelicense[i].RemainingLicenseUnit;
                        }
                        else if (Function.availablelicense[i].Type == "Terminal")
                        {
                            LicenseTerminalPanel.Visibility = Visibility.Visible;
                            txtTotalLicenseTerminal.Text = Function.availablelicense[i].Unit;
                            txtExpiryLicenseTerminal.Text = Function.availablelicense[i].ExpiryDate;
                            txtRemainingLicenseTerminal.Text = Function.availablelicense[i].RemainingLicenseUnit;
                        }
                    }
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString());
            }
        }

        #region Hyperlink 
        private void Hyperlink_RequestNavigate(object sender, RequestNavigateEventArgs e)
        {
            Process.Start(new ProcessStartInfo(e.Uri.AbsoluteUri));
            e.Handled = true;
        }
        #endregion

        #region Buttons Functions
        private void btnRefresh_Click(object sender, RoutedEventArgs e)
        {
            this.Cursor = Cursors.Wait;
            BackgroundWorker worker = new BackgroundWorker();
            worker.RunWorkerAsync();
            worker.DoWork += delegate(object s, DoWorkEventArgs args)
            {
                try
                {
                    Function.RefreshSDK();
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.ToString());
                }
            };
            worker.RunWorkerCompleted += delegate(object s, RunWorkerCompletedEventArgs args)
            {
                BindSidePanel(Login.SecurityToken);
                this.Cursor = Cursors.Arrow;
            };
        }

        private void btnClose_Click(object sender, RoutedEventArgs e)
        {
            Window parentWindow = Window.GetWindow(this);
            parentWindow.Close();
        }

        private void btnMinimize_Click(object sender, RoutedEventArgs e)
        {
            Window parentWindow = Window.GetWindow(this);
            parentWindow.WindowState = WindowState.Minimized;
        }

        private void btnSignOut_Click(object sender, RoutedEventArgs e)
        {
            LogoutResult logout = Function.LoadDataFromWebservice("Logout") as LogoutResult;
            string status = logout.Status;
            if (status == "Success")
            {
                if (Function.attendanceresult != null)
                {
                    Function.attendanceresult = null;
                }
                Login.SecurityToken = "";
                Login.CompanyID = "";
                MessageBox.Show("Signed out successfully!");
                Login login = new Login();
                App.Current.MainWindow = login;
                Window parentWindow = Window.GetWindow(this);
                parentWindow.Close();
                login.Show();
            }
            else
            {
                MessageBox.Show("Signout failed!");
            }
        }

        #endregion

        #region ComboBox
        public class Refresh
        {
            public string name { get; set; }
            public string value { get; set; }
        }

        private void cbRefreshInterval_Loaded(object sender, RoutedEventArgs e)
        {
            int selected = 1;
            List<Refresh> data = new List<Refresh>();
            data.Add(new Refresh { name = "Refresh Interval - 15 mins", value = "15" });
            data.Add(new Refresh { name = "Refresh Interval - 30 mins", value = "30" });
            data.Add(new Refresh { name = "Refresh Interval - 1 hour", value = "60" });
            data.Add(new Refresh { name = "Refresh Interval - 2 hours", value = "120" });
            data.Add(new Refresh { name = "Refresh Interval - 3 hours", value = "180" });

            var comboBox = sender as ComboBoxEdit;
            comboBox.ItemsSource = data;
            comboBox.DisplayMember = "name";
            comboBox.ValueMember = "value";

            try
            {
                string filename = "configuration.cfg";
                string line = "";
                if (File.Exists(filename))
                {
                    using (TextReader tr = new StreamReader(filename))
                    {
                        while ((line = tr.ReadLine()) != null)
                        {
                            string[] l = line.Split(new string[] { "_seperator_" }, StringSplitOptions.None);
                            if (l[0] == "RefreshInterval")
                            {
                                selected = Convert.ToInt32(l[1]);
                                break;
                            }
                        }
                        tr.Close();
                    }
                }

                comboBox.SelectedIndex = selected;
            }
            catch { }
        }

        private void cbRefreshInterval_SelectedIndexChanged(object sender, RoutedEventArgs e)
        {
            var comboBox = sender as ComboBoxEdit;
            string value = comboBox.EditValue as string;
            Function.refreshinterval = value;

            #region Save into configuration.cfg
            try
            {
                FileStream fs = null;
                string filename = "configuration.cfg";
                string line = "";
                string newline = "";
                string stringInFile = "";
                bool replaced = false;
                if (!File.Exists(filename))
                {
                    //Create
                    using (fs = File.Create(filename))
                    {
                    }
                    fs.Close();
                }
                if (File.Exists(filename))
                {
                    stringInFile = File.ReadAllText(filename);

                    using (TextReader tr = new StreamReader(filename))
                    {
                        while ((line = tr.ReadLine()) != null)
                        {
                            string[] l = line.Split(new string[] { "_seperator_" }, StringSplitOptions.None);
                            if (l[0] == "RefreshInterval")
                            {
                                //Replace
                                newline = "RefreshInterval_seperator_" + comboBox.SelectedIndex;
                                stringInFile = stringInFile.Replace(line, newline);
                                replaced = true;
                                break;
                            }
                        }
                        tr.Close();
                    }
                    if (replaced)
                    {
                        File.WriteAllText(filename, stringInFile);
                    }
                    if (!replaced)
                    {
                        //Write
                        using (StreamWriter sw = new StreamWriter(filename, append: true))
                        {
                            sw.WriteLine("RefreshInterval_seperator_" + comboBox.SelectedIndex);
                            sw.Close();
                        }
                    }
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString());
            }
            #endregion
        }
        #endregion

        
    }
}
