﻿using DevExpress.Internal.DXWindow;
using DevExpress.Xpf.Grid;
using DevExpress.XtraGrid.Views.Base;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Windows.Threading;
using TimeTecAPIDemo.Model;

namespace TimeTecAPIDemo
{
    /// <summary>
    /// Interaction logic for UserInfo.xaml
    /// </summary>
    public partial class UserInfo : UserControl
    {
        RowData dRow;
        public UserInfo()
        {
            InitializeComponent();
            LoadData();
        }

        public void LoadData()
        {
            this.Cursor = Cursors.Wait;
            BackgroundWorker worker = new BackgroundWorker();
            worker.RunWorkerAsync();
            worker.DoWork += delegate(object s, DoWorkEventArgs args)
            {
                try
                {
                    #region Initialize table User Info
                    if (Function.userinforesult == null)
                    {
                        Function.userinforesult = Function.LoadDataFromWebservice("UserInfo");
                    }
                    #endregion

                    #region Initialize master detail
                    List<UsersObj> obj = Function.userinforesult as List<UsersObj>;
                    if (obj != null)
                    {
                        foreach (UsersObj o in obj)
                        {
                            o.Fingerprint_9 = new List<FingerprintO>();
                            o.Fingerprint_10 = new List<FingerprintO>();
                        }
                    }
                    #endregion
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.ToString());
                }
            };
            worker.RunWorkerCompleted += delegate(object s, RunWorkerCompletedEventArgs args)
            {
                grid.ItemsSource = Function.userinforesult;
                this.Cursor = Cursors.Arrow;
                copyright.Text = copyright.Text.Replace("2015", DateTime.Now.Year.ToString());
            };
        }

        #region Grid function
        private void grid_MasterRowExpanded(object sender, DevExpress.Xpf.Grid.RowEventArgs e)
        {
            try
            {
                string User_ID = "";
                UsersObj obj = null;

                this.Cursor = Cursors.Wait;
                BackgroundWorker worker = new BackgroundWorker();
                worker.DoWork += delegate(object s, DoWorkEventArgs args)
                {
                    grid.BeginDataUpdate();
                    //Different thread
                    this.Dispatcher.Invoke((Action)(() =>
                    {
                        User_ID = grid.GetFocusedRowCellDisplayText("User_ID");
                        Function.FingerprintUserID = User_ID;
                        Function.FingerprintAlgoVer = "9";
                        Function.fingerprintresult9 = Function.LoadDataFromWebservice("Fingerprint");
                        Function.FingerprintAlgoVer = "10";
                        Function.fingerprintresult10 = Function.LoadDataFromWebservice("Fingerprint");
                    }));
                    //Different thread
                    this.Dispatcher.Invoke((Action)(() =>
                    {
                        obj = grid.GetFocusedRow() as UsersObj;
                        if (obj != null)
                        {
                            List<FingerprintObj> newList9 = (List<FingerprintObj>)Function.fingerprintresult9;
                            List<FingerprintObj> newList10 = (List<FingerprintObj>)Function.fingerprintresult10;

                            obj.Fingerprint_9.Clear();
                            obj.Fingerprint_10.Clear();

                            #region Set Algo 9 Object
                            if (newList9.Count > 0)
                            {
                                if (newList9[0].Fp0 != "")
                                    obj.Fingerprint_9.Add(new FingerprintO() { Fingerprint = "fp0", Template = newList9[0].Fp0 });
                                if (newList9[0].Fp1 != "")
                                    obj.Fingerprint_9.Add(new FingerprintO() { Fingerprint = "fp1", Template = newList9[0].Fp1 });
                                if (newList9[0].Fp2 != "")
                                    obj.Fingerprint_9.Add(new FingerprintO() { Fingerprint = "fp2", Template = newList9[0].Fp2 });
                                if (newList9[0].Fp3 != "")
                                    obj.Fingerprint_9.Add(new FingerprintO() { Fingerprint = "fp3", Template = newList9[0].Fp3 });
                                if (newList9[0].Fp4 != "")
                                    obj.Fingerprint_9.Add(new FingerprintO() { Fingerprint = "fp4", Template = newList9[0].Fp4 });
                                if (newList9[0].Fp5 != "")
                                    obj.Fingerprint_9.Add(new FingerprintO() { Fingerprint = "fp5", Template = newList9[0].Fp5 });
                                if (newList9[0].Fp6 != "")
                                    obj.Fingerprint_9.Add(new FingerprintO() { Fingerprint = "fp6", Template = newList9[0].Fp6 });
                                if (newList9[0].Fp7 != "")
                                    obj.Fingerprint_9.Add(new FingerprintO() { Fingerprint = "fp7", Template = newList9[0].Fp7 });
                                if (newList9[0].Fp8 != "")
                                    obj.Fingerprint_9.Add(new FingerprintO() { Fingerprint = "fp8", Template = newList9[0].Fp8 });
                                if (newList9[0].Fp9 != "")
                                    obj.Fingerprint_9.Add(new FingerprintO() { Fingerprint = "fp9", Template = newList9[0].Fp9 });
                            }
                            else if (newList9.Count == 0 || obj.Fingerprint_9.Count == 0)
                            {
                                obj.Fingerprint_9.Add(new FingerprintO() { Fingerprint = "", Template = "" });
                            }
                            #endregion
                            #region Set Algo 10 Object
                            if (newList10.Count > 0)
                            {
                                if (newList10[0].Fp0 != "")
                                    obj.Fingerprint_10.Add(new FingerprintO() { Fingerprint = "fp0", Template = newList10[0].Fp0 });
                                if (newList10[0].Fp1 != "")
                                    obj.Fingerprint_10.Add(new FingerprintO() { Fingerprint = "fp1", Template = newList10[0].Fp1 });
                                if (newList10[0].Fp2 != "")
                                    obj.Fingerprint_10.Add(new FingerprintO() { Fingerprint = "fp2", Template = newList10[0].Fp2 });
                                if (newList10[0].Fp3 != "")
                                    obj.Fingerprint_10.Add(new FingerprintO() { Fingerprint = "fp3", Template = newList10[0].Fp3 });
                                if (newList10[0].Fp4 != "")
                                    obj.Fingerprint_10.Add(new FingerprintO() { Fingerprint = "fp4", Template = newList10[0].Fp4 });
                                if (newList10[0].Fp5 != "")
                                    obj.Fingerprint_10.Add(new FingerprintO() { Fingerprint = "fp5", Template = newList10[0].Fp5 });
                                if (newList10[0].Fp6 != "")
                                    obj.Fingerprint_10.Add(new FingerprintO() { Fingerprint = "fp6", Template = newList10[0].Fp6 });
                                if (newList10[0].Fp7 != "")
                                    obj.Fingerprint_10.Add(new FingerprintO() { Fingerprint = "fp7", Template = newList10[0].Fp7 });
                                if (newList10[0].Fp8 != "")
                                    obj.Fingerprint_10.Add(new FingerprintO() { Fingerprint = "fp8", Template = newList10[0].Fp8 });
                                if (newList10[0].Fp9 != "")
                                    obj.Fingerprint_10.Add(new FingerprintO() { Fingerprint = "fp9", Template = newList10[0].Fp9 });
                            }
                            else if (newList10.Count == 0 || obj.Fingerprint_10.Count == 0)
                            {
                                obj.Fingerprint_10.Add(new FingerprintO() { Fingerprint = "", Template = "" });
                            }
                            #endregion
                        }

                        grid.EndDataUpdate();
                        grid.RefreshData();
                    }));
                };
                worker.RunWorkerAsync();
                while (worker.IsBusy)
                {
                    System.Threading.Thread.Sleep(100);
                    MainWindow.DoEvents();
                }
                this.Cursor = Cursors.Arrow;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString());
            }
        }
        #endregion

        #region Buttons Functions
        private void btnRefreshGrid_Click(object sender, RoutedEventArgs e)
        {
            this.Cursor = Cursors.Wait;
            BackgroundWorker worker = new BackgroundWorker();
            worker.RunWorkerAsync();
            worker.DoWork += delegate(object s, DoWorkEventArgs args)
            {
                try
                {
                    Function.userinforesult = Function.LoadDataFromWebservice("UserInfo");

                    #region Initialize master detail
                    List<UsersObj> obj = Function.userinforesult as List<UsersObj>;
                    if (obj != null)
                    {
                        foreach (UsersObj o in obj)
                        {
                            o.Fingerprint_9 = new List<FingerprintO>();
                            o.Fingerprint_10 = new List<FingerprintO>();
                        }
                    }
                    #endregion
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.ToString());
                }
            };
            worker.RunWorkerCompleted += delegate(object s, RunWorkerCompletedEventArgs args)
            {
                grid.BeginDataUpdate();
                grid.ItemsSource = Function.userinforesult;
                grid.EndDataUpdate();
                grid.RefreshData();
                this.Cursor = Cursors.Arrow;
            };
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                if (dRow == null)
                    return;

                FingerprintO fprow = dRow.Row as FingerprintO;
                if (null != fprow)
                {
                    Clipboard.SetText(fprow.Template.ToString());
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString());
            }
        }

        private void btnClose_Click(object sender, RoutedEventArgs e)
        {
            Window parentWindow = Window.GetWindow(this);
            parentWindow.Close();
        }

        private void btnMinimize_Click(object sender, RoutedEventArgs e)
        {
            Window parentWindow = Window.GetWindow(this);
            parentWindow.WindowState = WindowState.Minimized;
        }
        #endregion

        #region Get clicked master-detail grid row
        private void tableView910_PreviewMouseDown(object sender, MouseButtonEventArgs e)
        {
            TableView view = sender as TableView;
            TableViewHitInfo hitInfo = view.CalcHitInfo(e.OriginalSource as DependencyObject);
            if (hitInfo.InRow)
            {
                var item = view.GetRowElementByRowHandle(hitInfo.RowHandle);
                dRow = (RowData)item.DataContext;
            }
        }
        #endregion

        private void btnEditUser_Click(object sender, RoutedEventArgs e)
        {
            Function.UserID = grid.GetFocusedRowCellDisplayText("User_ID");
            string Company_ID = grid.GetFocusedRowCellDisplayText("Company_ID");
            EditUserInfo EditUserInfo = new EditUserInfo();
            EditUserInfo.ShowDialog();
            //MessageBox.Show(User_ID);
        }

        private void InsertUserbtn_Click(object sender, RoutedEventArgs e)
        {
            InserUserForm InsertUserForm = new InserUserForm();
            InsertUserForm.ShowDialog();
        }
    }

    #region Set visibility of Copy to Clipboard button
    public class VisibilityConverter : System.Windows.Markup.MarkupExtension, IValueConverter
    {
        #region IValueConverter Members

        public VisibilityConverter()
        {
        }

        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (parameter == null && value == null)
                return null;

            if (value.ToString() == string.Empty)
                return Visibility.Hidden;
            else
                return Visibility.Visible;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }

        public override object ProvideValue(IServiceProvider serviceProvider)
        {
            return this;
        }

        #endregion
    }
    #endregion
}
